package config

import (
	"github.com/BurntSushi/toml"
	log "github.com/sirupsen/logrus"
	"io/ioutil"
)

type MysqlConfig struct {
	Host   string `json:"host" toml:"host"`
	Port   int    `json:"port" toml:"port"`
	User   string `json:"user" toml:"user"`
	Passwd string `json:"password" toml:"password"`
	DbName string `json:"database" toml:"database"`
}

type KafkaConfig struct {
	Brokers      string `json:"brokers" toml:"brokers"`
	ReceiptTopic string `json:"receipt_topic" toml:"receipt_topic"`
	TaskTopic    string `json:"task_topic" toml:"task_topic"`
}

type RedisConfig struct {
	Addr     string `json:"addr" toml:"addr"`
	Password string `json:"password" toml:"password"`
	DbIndex  int    `json:"db_index" toml:"db_index"`
}

type TickerConfig struct {
	HeartBeat         int `json:"heart_beat" toml:"heart_beat"`
	StatusTicker      int `json:"status_ticker" toml:"status_ticker"`
	DeviceInfoTicker  int `json:"device_info_ticker" toml:"device_info_ticker"`
	DeviceUsageTicker int `json:"device_usage_ticker" toml:"device_usage_ticker"`
}

type Config struct {
	PrivateKey string       `json:"private_key" toml:"private_key"`
	Endpoint   string       `json:"endpoint" toml:"endpoint"`
	MetricPort int          `json:"metrics_port" toml:"metrics_port"`
	EnablePay  bool         `json:"enable_pay" toml:"enable_pay"`
	Redis      RedisConfig  `json:"redis" toml:"redis"`
	DbConfig   MysqlConfig  `json:"mysql" toml:"mysql"`
	Tickers    TickerConfig `json:"ticker" toml:"ticker"`
	Kafka      KafkaConfig  `json:"kafka" toml:"kafka"`
}

var _cfg *Config = nil

func ParseConfig(path string) (*Config, error) {
	data, err := ioutil.ReadFile(path)
	if err != nil {
		log.Error("get config failed", "err", err)
		panic(err)
	}
	err = toml.Unmarshal(data, &_cfg)
	// err = json.Unmarshal(data, &_cfg)
	if err != nil {
		log.Error("unmarshal config failed", "err", err)
		panic(err)
	}
	return _cfg, nil
}

func GetConfig() *Config {
	return _cfg
}
